﻿local L = LibStub("AceLocale-3.0"):GetLocale("GigaItemAuction", false)

local _G				= getfenv(0)

local pairs			    = _G.pairs
local ipairs			= _G.ipairs
local select			= _G.select

local table_insert		= _G.table.insert
local table_remove		= _G.table.remove
local table_sort		= _G.table.sort



local PLAYERNAME 		= UnitName("player")
local _, PLAYERCLASS 	= UnitClass("player")
local PLAYERGUID 		= 0

local db

function GigaItemAuction:OPTIONSOnInitialize()
	db = self.db.profile
end

function GigaItemAuction:GetOptionsConfig()
	PLAYERGUID 	= self:getMyGUID()
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	local dbs = db.auctionSecurity
	
	local addonEntwickler = {["Lolitchen"]=true, ["Gigadrone"]=true, ["Ninnie"]=true}
	local options = {
		type = 'group',
		name = L["GigaItemAuction"],
		icon = "Interface\\AddOns\\GigaItemAuction\\Icons\\SyncON",
		args = {
			General = {
				order = 1,
				type = "group",
				name = L["General Settings"],
				desc = L["General Settings"],
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["GIA_DESC"],
					},
					show = {
						type = 'execute',
						name = L["Toggle GIA"],
						desc = L["ShowGIAText"],
						func = function()
							GigaItemAuction:ToggleAUCTIONFrame()
						end,
						order = 10,
					},
					showadmin = {
						type = 'execute',
						name = L["Admin GIA"],
						desc = L["ShowADMINText"],
						func = function()
							GigaItemAuction:ShowADMINFrame()
						end,
						order = 20,
						hidden = function()
							if GigaItemAuction:CheckSecurity(PLAYERNAME, 'admin') then
								return false
							end
							return true
						end,
					},
					checkVersion = {
						type = 'execute',
						name = L["VersionCheck"],
						desc = L["VersionCheckText"], 
						func = function()
							GigaItemAuction:VersionChecks()
						end,
						order = 30,
					},
					debugoption = {
						type = 'group',
						name = L["GIA_DEBUG"],
						guiInline = true,
						order = 60,
						get = function(info) return dbc[ info[#info] ] end,
						set = function(info, value)
							dbc[ info[#info] ] = value
							self:ToggleDebugLog(db.config.debugadmin, db.config.debugframe)
						end,
						args = {
							debugmodus = {
								type = 'toggle',
								name = L["DebugModus"],
								desc = L["DebugModusText"],
								order = 1,
							},
							debugadmin = {
								type = 'toggle',
								name = L["DebugAdmin"],
								desc = L["DebugAdminText"],
								order = 2,
								hidden = function() return not addonEntwickler[PLAYERNAME] end,
							},
							debugframe = {
								type = 'toggle',
								name = L["DebugFrame"],
								desc = L["DebugFrameText"],
								order = 3,
								hidden = function() return not addonEntwickler[PLAYERNAME] end,
								disabled = function() return not db.config.debugadmin end,
							},
						},
					},
				},
			},	
			bidStep = {
				type = 'group',
				name = L["BidStepText"],
				desc = L["BidStepText"],
				order = 40,
				get = function(info) return dbc.bidStep[ info[#info] ] end,
				set = function(info, value)
					dbc.bidStep[ info[#info] ] = value
					self:SetAuctionBidStats()
				end,
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["BidStepText_DESC"],
					},
					step1 = {
						type = 'range',
						name = L["1st BidButton"],
						desc = L["BidOptionText"],
						min = dba.bidStep,
						max = dba.bidStep * 25,
						step = dba.bidStep,
						order = 2,
						disabled = true,
					},
					step2 = {
						type = 'range',
						name = L["2nd BidButton"],
						desc = L["BidOptionText"],
						min = dba.bidStep,
						max = dba.bidStep * 25,
						step = dba.bidStep,
						order = 3,
					},
					step3 = {
						type = 'range',
						name = L["3rd BidButton"],
						desc = L["BidOptionText"],
						min = dba.bidStep,
						max = dba.bidStep * 25,
						step = dba.bidStep,
						order = 4,
					},
					step4 = {
						type = 'range',
						name = L["4th BidButton"],
						desc = L["BidOptionText"],
						min = dba.bidStep,
						max = dba.bidStep * 25,
						step = dba.bidStep,
						order = 5,
					},
				},
			},		
			soundOption = {
				type = 'group',
				name = L["SoundOptionText"],
				desc = L["SoundOptionText"],
				order = 1,
				get = function(info) return dbc.playsound[ info[#info] ] end,
				set = function(info, value)
					dbc.playsound[ info[#info] ] = value
				end,
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["SoundOptionText"],
					},
					auctionstart = {
						type = 'toggle',
						name = L["Sound_auctionstart"],
						desc = L["Sound_auctionstartText"],
						order = 2,
					},
					auctionend = {
						type = 'toggle',
						name = L["Sound_auctionend"],
						desc = L["Sound_auctionendText"],
						order = 3,
					},
					newgebot = {
						type = 'toggle',
						name = L["Sound_newgebot"],
						desc = L["Sound_newgebotText"],
						order = 4,
					},
					backgebot = {
						type = 'toggle',
						name = L["Sound_backgebot"],
						desc = L["Sound_backgebotText"],
						order = 5,
					},
					pause = {
						type = 'toggle',
						name = L["Sound_pause"],
						desc = L["Sound_pauseText"],
						order = 6,
					},
					pausestart = {
						type = 'toggle',
						name = L["Sound_pausestart"],
						desc = L["Sound_pausestartText"],
						order = 7,
					},
					errormsg = {
						type = 'toggle',
						name = L["Sound_errormsg"],
						desc = L["Sound_errormsgText"],
						order = 8,
					},
					longauction = {
						type = 'toggle',
						name = L["Sound_longauction"],
						desc = L["Sound_longauctionText"],
						order = 9,
					},
				},
			},
			ItemFilter = {
				order = 1,
				type = "group",
				name = L["Filter Settings"],
				desc = L["Filter Settings"],
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["GIA_FILTER"],
					},
					showAll = {
						type = 'toggle',
						name = L["itemFilter_showAll"],
						order = 2,
						get = function(info) return db.filter.itemType.showAll end,
						set = function(info, value)
							db.filter.itemType.showAll = value
						end,
					},
					printFilterBlock = {
						type = 'toggle',
						name = L["itemFilter_printFilterBlock"],
						order = 3,
						get = function(info) return db.config.printFilterBlock end,
						set = function(info, value)
							db.config.printFilterBlock = value
						end,
					},
					itemType = {
						type = 'group',
						name = L["Category"],
						guiInline = true,
						order = 10,
						get = function(info) return db.filter.itemType[ info[#info] ] end,
						set = function(info, value)
							db.filter.itemType[ info[#info] ] = value
						end,
						hidden = function() return db.filter.itemType.showAll end,	
						args = {
							Weapon = {
								type = 'toggle',
								name = L["Weapon"],
								order = 1,
							},
							Armor = {
								type = 'toggle',
								name = L["Armor"],
								order = 2,
							},
							Miscellaneous = {
								type = 'toggle',
								name = L["Armor Token"],
								desc = L["Tierset token"],
								order = 3,
							},
							Gem = {
								type = 'toggle',
								name = L["Gem"],
								order = 4,
							},
							Trade_Goods = {
								type = 'toggle',
								name = L["Trade Goods"],
								order = 5,
							},
							Recipe = {
								type = 'toggle',
								name = L["Recipe"],
								order = 6,
							},
						},
					},
					Armor = {
						type = 'group',
						name = L["Armor"],
						guiInline = true,
						order = 20,
						get = function(info) return db.filter.itemSubType[ info[#info] ] end,
						set = function(info, value)
							db.filter.itemSubType[ info[#info] ] = value
						end,
						disabled = function() return not db.filter.itemType.Armor end,
						hidden = function() return db.filter.itemType.showAll or not db.filter.itemType.Armor end,	
						args = {
							Plate = {				--Head, Shoulder, Chest, Waist, Legs, Feet, Wrist, Hands
								type = 'toggle',
								name = L["Plate"],
								desc = L["Head"].."\n"..L["Shoulder"].."\n"..L["Chest"].."\n"..L["Waist"].."\n"..L["Legs"].."\n"..L["Feet"].."\n"..L["Wrist"].."\n"..L["Hands"],
								order = 1,
							},
							Mail = {				--Head, Shoulder, Chest, Waist, Legs, Feet, Wrist, Hands
								type = 'toggle',
								name = L["Mail"],
								desc = L["Head"].."\n"..L["Shoulder"].."\n"..L["Chest"].."\n"..L["Waist"].."\n"..L["Legs"].."\n"..L["Feet"].."\n"..L["Wrist"].."\n"..L["Hands"],
								order = 2,
							},
							Leather = {				--Head, Shoulder, Chest, Waist, Legs, Feet, Wrist, Hands
								type = 'toggle',
								name = L["Leather"],
								desc = L["Head"].."\n"..L["Shoulder"].."\n"..L["Chest"].."\n"..L["Waist"].."\n"..L["Legs"].."\n"..L["Feet"].."\n"..L["Wrist"].."\n"..L["Hands"],
								order = 3,
							},
							Cloth = {				--Head, Shoulder, Chest, Waist, Legs, Feet, Wrist, Hands, Back
								type = 'toggle',
								name = L["Cloth"],
								desc = L["Head"].."\n"..L["Shoulder"].."\n"..L["Robe"].."\n"..L["Waist"].."\n"..L["Legs"].."\n"..L["Feet"].."\n"..L["Wrist"].."\n"..L["Hands"].."\n"..L["Back"],
								order = 4,
							},
							Miscellaneous = {		--Head, Neck, Shirt, Finger, Trinket, Held In Off-hand
								type = 'toggle',
								name = L["Miscellaneous"],
								desc = L["Neck"].."\n"..L["Finger"].."\n"..L["Trinket"].."\n"..L["Held In Off-hand"].."\n"..L["Head"].." ("..L["Engineering"]..", "..L["Event"]..", ...)",
								order = 5,
							},
							Shields = {
								type = 'toggle',
								name = L["Shields"],
								order = 6,
							},
							itemEquipLoc = {
								type = 'group',
								name = L["Armor"].." "..L["Slot"],
								guiInline = true,
								order = 7,
								get = function(info) return db.filter.itemEquipLoc[ info[#info] ] end,
								set = function(info, value)
									db.filter.itemEquipLoc[ info[#info] ] = value
								end,
								hidden = function() return not db.filter.itemType.Armor or (not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth and not db.filter.itemSubType.Miscellaneous) end,
								args = {
	--Head, 		Shoulder, 		  Robe, 		Chest,		   Waist, 		  Legs, 		Feet, 		  Wrist, 		 Hands, 	   Back
	--Kopf, 		Schulter, 		  Robe, 		Brust,		   Taile, 		  Beine, 		Fuesse, 	  Handgelenke,   Haende, 	   Ruecken
	--INVTYPE_HEAD, INVTYPE_SHOULDER, INVTYPE_ROBE, INVTYPE_CHEST, INVTYPE_WAIST, INVTYPE_LEGS, INVTYPE_FEET, INVTYPE_WRIST, INVTYPE_HAND, INVTYPE_CLOAK
									INVTYPE_HEAD = {
										type = 'toggle',
										name = L["Head"],
										order = 1,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth and not db.filter.itemSubType.Miscellaneous end,
									},
									INVTYPE_SHOULDER = {
										type = 'toggle',
										name = L["Shoulder"],
										order = 2,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_ROBE = {
										type = 'toggle',
										name = L["Robe"],
										order = 3,
										disabled = function() return not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_CHEST = {
										type = 'toggle',
										name = L["Chest"],
										order = 4,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather end,
									},
									INVTYPE_WAIST = {
										type = 'toggle',
										name = L["Waist"],
										order = 5,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_LEGS = {
										type = 'toggle',
										name = L["Legs"],
										order = 6,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_FEET = {
										type = 'toggle',
										name = L["Feet"],
										order = 7,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_WRIST = {
										type = 'toggle',
										name = L["Wrist"],
										order = 8,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_HAND = {
										type = 'toggle',
										name = L["Hands"],
										order = 9,
										disabled = function() return not db.filter.itemSubType.Plate and not db.filter.itemSubType.Mail and not db.filter.itemSubType.Leather and not db.filter.itemSubType.Cloth end,
									},
									INVTYPE_CLOAK = {
										type = 'toggle',
										name = L["Back"],
										order = 10,
										disabled = function() return not db.filter.itemSubType.Cloth end,
									},
	--Head, 		Neck, 		  Shirt, 		Finger, 			  Trinket, 				Held In Off-hand
	--Kopf, 		Hals,		  Hemd,			Finger,				  Schmuck,				In Schildhand gefuehrt
	--INVTYPE_HEAD, INVTYPE_NECK, INVTYPE_BODY, INVTYPE_FINGER,		  INVTYPE_TRINKET,		INVTYPE_HOLDABLE
									INVTYPE_NECK = {
										type = 'toggle',
										name = L["Neck"],
										order = 11,
										disabled = function() return not db.filter.itemSubType.Miscellaneous end,
									},
									INVTYPE_FINGER = {
										type = 'toggle',
										name = L["Finger"],
										order = 12,
										disabled = function() return not db.filter.itemSubType.Miscellaneous end,
									},
									INVTYPE_TRINKET = {
										type = 'toggle',
										name = L["Trinket"],
										order = 13,
										disabled = function() return not db.filter.itemSubType.Miscellaneous end,
									},
									INVTYPE_HOLDABLE = {
										type = 'toggle',
										name = L["Held In Off-hand"],
										order = 14,
										disabled = function() return not db.filter.itemSubType.Miscellaneous end,
									},
								},
							},
							other_Relic = {
								type = 'toggle',
								name = L["Relic"],
								desc =  L["Librams"].."\n"..L["Idols"].."\n"..L["Totems"].."\n"..L["Sigils"],
								order = 8,
							},
							itemSubType2 = {
								type = 'group',
								name = L["Relic"].." "..L["Slot"],
								guiInline = true,
								order = 9,
								get = function(info) return db.filter.itemSubType[ info[#info] ] end,
								set = function(info, value)
									db.filter.itemSubType[ info[#info] ] = value
								end,
								hidden = function() return not db.filter.itemType.Armor or not db.filter.itemSubType.other_Relic end,								
								args = {
									Librams = {
										type = 'toggle',
										name = L["Librams"],
										order = 1,
										disabled = function() return not db.filter.itemSubType.other_Relic end,
									},
									Idols = {
										type = 'toggle',
										name = L["Idols"],
										order = 2,
										disabled = function() return not db.filter.itemSubType.other_Relic end,
									},
									Totems = {
										type = 'toggle',
										name = L["Totems"],
										order = 3,
										disabled = function() return not db.filter.itemSubType.other_Relic end,
									},
									Sigils = {
										type = 'toggle',
										name = L["Sigils"],
										order = 4,
										disabled = function() return not db.filter.itemSubType.other_Relic end,
									},
								},
							},
						},
					},
					Gem = {
						type = 'group',
						name = L["Gem"],
						guiInline = true,
						order = 30,
						get = function(info) return db.filter.itemSubType[ info[#info] ] end,
						set = function(info, value)
							db.filter.itemSubType[ info[#info] ] = value
						end,
						disabled = function() return not db.filter.itemType.Gem end,
						hidden = function() return db.filter.itemType.showAll or not db.filter.itemType.Gem end,
						args = {
							Red = {
								type = 'toggle',
								name = L["Red"],
								order = 1,
							},
							Blue = {
								type = 'toggle',
								name = L["Blue"],
								order = 2,
							},
							Yellow = {
								type = 'toggle',
								name = L["Yellow"],
								order = 3,
							},
							Purple = {
								type = 'toggle',
								name = L["Purple"],
								order = 4,
							},
							Green = {
								type = 'toggle',
								name = L["Green"],
								order = 5,
							},
							Orange = {
								type = 'toggle',
								name = L["Orange"],
								order = 6,
							},
							other_Gem = {
								type = 'toggle',
								name = L["other"],
								desc =  L["Meta"].."\n"..L["Prismatic"].."\n"..L["Simple"],
								order = 7,
							},
						},
					},
					Recipe = {
						type = 'group',
						name = L["Recipe"],
						guiInline = true,
						order = 40,
						get = function(info) return db.filter.itemSubType[ info[#info] ] end,
						set = function(info, value)
							db.filter.itemSubType[ info[#info] ] = value
						end,
						disabled = function() return not db.filter.itemType.Recipe end,
						hidden = function() return db.filter.itemType.showAll or not db.filter.itemType.Recipe end,
						args = {
							Leatherworking = {
								type = 'toggle',
								name = L["Leatherworking"],
								order = 1,
							},
							Tailoring = {
								type = 'toggle',
								name = L["Tailoring"],
								order = 2,
							},
							Engineering = {
								type = 'toggle',
								name = L["Engineering"],
								order = 3,
							},
							Blacksmithing = {
								type = 'toggle',
								name = L["Blacksmithing"],
								order = 4,
							},
							Jewelcrafting = {
								type = 'toggle',
								name = L["Jewelcrafting"],
								order = 5,
							},
							Enchanting = {
								type = 'toggle',
								name = L["Enchanting"],
								order = 6,
							},
							Alchemy = {
								type = 'toggle',
								name = L["Alchemy"],
								order = 7,
							},
							other_Recipe = {
								type = 'toggle',
								name = L["other"],
								desc =  L["Cooking"].."\n"..L["First Aid"].."\n"..L["Fishing"].."\n"..L["Book"],
								order = 8,
							},
						},
					},					
				},
			},			
			Admin = {
				order = 1,
				type = "group",
				name = L["Admin Settings"],
				desc = L["Admin Settings"],
				get = function(info) return dba[ info[#info] ] end,
				set = function(info, value)
					self:Debug("|cffb277b1OPTIONS:|r - Admin - key:%s, value:%s", "db.admin."..info[#info], ((type(value) == "boolean") and (value and 'true' or 'false') or value))
					
					if self.auctionStatusSTART and info[#info] == 'bidTime' then
						self:Print("|cffff5555ERROR:|r - The auction is started. Please wait...")
					else
						dba[info[#info]] = value
						GigaItemAuction:SendAdminEditOption(info[#info])
					end
				end,
				disabled = function() return not GigaItemAuction:CheckSecurity(PLAYERNAME, 'admin') end,
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["GIA_ADMIN"],
					},
					bidStep = {
						type = 'range',
						name = L["admin_option_bidStep"],
						desc = L["admin_option_bidStep_text"],
						min = 1,
						max = 10,
						step = 1,
						order = 2,
					},
					bidTime = {
						type = 'range',
						name = L["admin_option_bidTime"],
						desc = L["admin_option_bidTime_text"],
						min = 10,
						max = 120,
						step = 5,
						order = 3,
					},
					bidUP = {
						type = 'range',
						name = L["admin_option_bidU80"],
						desc = L["admin_option_bidU80_text"],
						min = 25,
						max = 95,
						step = 5,
						order = 4,
					},
					onlyAuctioneerACP = {
						type = 'toggle',
						name = L["admin_option_AuctioneerACP"],
						desc = L["admin_option_AuctioneerACP_text"],
						order = 5,
					},
					header = {
						type = 'header',
						name = '',
						order = 10,
					},
					bidWithdraw = {
						type = 'toggle',
						name = L["admin_option_bidWithdraw"],
						desc = L["admin_option_bidWithdraw_text"],
						order = 11,
					},
					bidderShow = {
						type = 'toggle',
						name = L["admin_option_bidderShow"],
						desc = L["admin_option_bidderShow_text"],
						order = 12,
					},
					bidArt = {
						type = 'group',
						name = L["admin_option_bidArt"],
						guiInline = true,
						order = 13,
						get = function(info) return dba.bidArt[ info[#info] ] end,
						set = function(info, value)
							
							self:Debug("|cffb277b1OPTIONS:|r - Admin - key:%s, value:%s", "db.admin.bidArt."..info[#info], ((type(value) == "boolean") and (value and 'true' or 'false') or value))
							
							dba.bidArt[info[#info]] = value
							GigaItemAuction:SendAdminEditOption(info[#info], 'bidArt')
						end,
						args = {
							main = {
								type = 'toggle',
								name = L["admin_option_bidArt_main"],
								desc = L["admin_option_bidArt_main_text"],
								order = 1,
							},
							second = {
								type = 'toggle',
								name = L["admin_option_bidArt_second"],
								desc = L["admin_option_bidArt_second_text"],
								order = 2,
							},
							fun = {
								type = 'toggle',
								name = L["admin_option_bidArt_fun"],
								desc = L["admin_option_bidArt_fun_text"],
								order = 3,
							},
							u80 = {
								type = 'toggle',
								name = L["admin_option_bidArt_u80"],
								desc = L["admin_option_bidArt_u80_text"],
								order = 4,
							},
						},
					},
					info = {
						type = 'group',
						name = L["admin_option_priority"],
						guiInline = true,
						order = 20,
						args = {
							infotext = {
								type = "description",
								name = L["admin_option_priority_text"],
							},
						},
					},
				},
			},
			guildRankRules = {
				order = 1,
				type = "group",
				name = L["GuildRank Rules Options"],
				desc = L["GuildRank Rules Options"],
				disabled = function() return not GigaItemAuction:CheckSecurity(PLAYERNAME, 'admin') end,
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["GIA_GUILDRANK"],
					},
					sync1 = {
						type = 'execute',
						name = "Sync GuildRank",
						func = function()
							GigaItemAuction:GuildLeaderSyncRulesSend()
						end,
						order = 2,
						disabled = function() return select(4, self:GetGuildPlayer(PLAYERNAME)) ~= 1 end,
					},
					sync2 = {
						type = 'execute',
						name = "Sync GuildRank",
						func = function()
							GigaItemAuction:GuildLeaderSyncRulesSend()
						end,
						order = 30,
						disabled = function() return select(4, self:GetGuildPlayer(PLAYERNAME)) ~= 1 end,
					},
				},
			},
			raidRankRules = {
				order = 1,
				type = "group",
				name = L["RaidRank Rules Options"],
				desc = L["RaidRank Rules Options"],
				disabled = function() return not self:CheckSecurity(PLAYERNAME, 'admin') end,
				args = {
					intro = {
						order = 1,
						type = "description",
						name = L["GIA_RAIDRANK"],
					},
					sync1 = {
						type = 'execute',
						name = "Sync RaidRank",
						func = function()
							GigaItemAuction:GuildLeaderSyncRulesSend()
						end,
						order = 2,
						disabled = function() return select(4, self:GetGuildPlayer(PLAYERNAME)) ~= 1 end,
					},
					rank1 = {
						type = 'group',
						name = L["RANK"].." #"..dbs.raidRank.rank1.rank..": |cff6288FF"..dbs.raidRank.rank1.name.."|r",
						guiInline = true,
						order = 11,
						get = function(info) return dbs.raidRank.rank1[info[#info]] end,
						set = function(info, value) 
							dbs.raidRank.rank1[info[#info]] = value
							self:AdminCurrentRulesSend()
						end,
						args = {
							pStart = {
								type = 'toggle',
								name = L["admin_option_start_auction"],
								desc = L["admin_option_start_auction_text"],
								order = 1,
							},
							pControl = {
								type = 'toggle',
								name = L["admin_option_control_auction"],
								desc = L["admin_option_control_auction_text"],
								order = 2,
							},
						},
					},
					rank2 = {
						type = 'group',
						name = L["RANK"].." #"..dbs.raidRank.rank2.rank..": |cff6288FF"..dbs.raidRank.rank2.name.."|r",
						guiInline = true,
						order = 12,
						get = function(info) return dbs.raidRank.rank2[info[#info]] end,
						set = function(info, value) 
							dbs.raidRank.rank2[info[#info]] = value
							self:AdminCurrentRulesSend()
						end,
						args = {
							pStart = {
								type = 'toggle',
								name = L["admin_option_start_auction"],
								desc = L["admin_option_start_auction_text"],
								order = 1,
							},
							pControl = {
								type = 'toggle',
								name = L["admin_option_control_auction"],
								desc = L["admin_option_control_auction_text"],
								order = 2,
							},
						},
					},
					rank3 = {
						type = 'group',
						name = L["RANK"].." #"..dbs.raidRank.rank3.rank..": |cff6288FF"..dbs.raidRank.rank3.name.."|r",
						guiInline = true,
						order = 13,
						get = function(info) return dbs.raidRank.rank3[info[#info]] end,
						set = function(info, value) 
							dbs.raidRank.rank3[info[#info]] = value
							self:AdminCurrentRulesSend()
						end,
						args = {
							pStart = {
								type = 'toggle',
								name = L["admin_option_start_auction"],
								desc = L["admin_option_start_auction_text"],
								order = 1,
							},
							pControl = {
								type = 'toggle',
								name = L["admin_option_control_auction"],
								desc = L["admin_option_control_auction_text"],
								order = 2,
							},
						},
					},
				},
			},
			FuBar = {
				order = -4,
				type = "group",
				name = L["FuBar Options"],
				desc = L["FuBar Options"],
				hidden = function() return GigaItemAuction.IsFuBarMinimapAttached == nil end,
				args = {
					hideIcon = {
						type = "toggle",
						order = 1,
						name = L["Hide minimap/FuBar icon"],
						desc = L["Hide minimap/FuBar icon"],
						get = function(info) return db.FuBar.HideMinimapButton end,
						set = function(info, v)
							db.FuBar.HideMinimapButton = v
							GigaItemAuction:UpdateFuBarSettings()
						end,
					},
					attachMinimap = {
						type = "toggle",
						order = 2,
						name = L["Attach to minimap"],
						desc = L["Attach to minimap"],
						get = function(info) return GigaItemAuction:IsFuBarMinimapAttached() end,
						set = function(info, v)
							GigaItemAuction:ToggleFuBarMinimapAttached()
							db.FuBar.AttachMinimap = GigaItemAuction:IsFuBarMinimapAttached()
						end,
						disabled = function() return db.FuBar.HideMinimapButton end,
					},
					showIcon = {
						type = "toggle",
						order = 3,
						name = L["Show icon"],
						desc = L["Show icon"],
						get = function(info) return GigaItemAuction:IsFuBarIconShown() end,
						set = function(info, v) GigaItemAuction:ToggleFuBarIconShown() end,
						disabled = GetFuBarMinimapAttachedStatus,
					},
					showText = {
						type = "toggle",
						order = 4,
						name = L["Show text"],
						desc = L["Show text"],
						get = function(info) return GigaItemAuction:IsFuBarTextShown() end,
						set = function(info, v) GigaItemAuction:ToggleFuBarTextShown() end,
						disabled = GetFuBarMinimapAttachedStatus,
					},
					position = {
						type = "select",
						order = 5,
						name = L["Position"],
						desc = L["Position"],
						values = {LEFT = L["Left"], CENTER = L["Center"], RIGHT = L["Right"]},
						get = function() return GigaItemAuction:GetPanel() and GigaItemAuction:GetPanel():GetPluginSide(GigaItemAuction) end,
						set = function(info, val)
							if GigaItemAuction:GetPanel() and GigaItemAuction:GetPanel().SetPluginSide then
								GigaItemAuction:GetPanel():SetPluginSide(GigaItemAuction, val)
							end
						end,
						disabled = GetFuBarMinimapAttachedStatus,
					}
				}
			},
		},
	}
	if IsInGuild() then
		for i, v in pairs(dbs.guildRank) do
			options.args.guildRankRules.args[i] = {
				type = 'group',
				name = (select(4, self:GetGuildPlayer(PLAYERNAME)) == v.rank and ("(|cffff0000"..L["Your rank"].."|r) • • ") or "")..L["RANK"].." #"..v.rank..": |cff6288FF"..dbs.guildRank["rank"..v.rank].name.."|r ",
				guiInline = true,
				order = v.rank + 10,
				get = function(info) return dbs.guildRank[i][info[#info]] end,
				set = function(info, value) 
					dbs.guildRank[i][info[#info]] = value
					self:AdminCurrentRulesSend()
				end,
				hidden = function() return dbs.guildRank["rank"..v.rank].name == "rank"..v.rank end,
				disabled = function()
					if v.rank > select(4, self:GetGuildPlayer(PLAYERNAME)) and self:CheckSecurity(PLAYERNAME, 'admin') then
						return false
					else
						return true
					end
				end,
				args = {
					bidMain = {
						type = 'toggle',
						name = "|cff55ff55 • |r"..L["to bid a [%s]"]:format("|cff55ff55"..L["admin_option_bidArt_main"].."|r"),
						desc = L["admin_option_bidArt_main_text"],
						order = 1,
					},
					bidSecond = {
						type = 'toggle',
						name = "|cff55ff55 • |r"..L["to bid a [%s]"]:format("|cff55ff55"..L["admin_option_bidArt_second"].."|r"),
						desc = L["admin_option_bidArt_second_text"],
						order = 2,
					},
					bidFun = {
						type = 'toggle',
						name = "|cff55ff55 • |r"..L["to bid a [%s]"]:format("|cff55ff55"..L["admin_option_bidArt_fun"].."|r"),
						desc = L["admin_option_bidArt_fun_text"],
						order = 3,
					},
					bidU80 = {
						type = 'toggle',
						name = "|cff55ff55 • |r"..L["admin_option_bidArt_u80"],
						desc = L["admin_option_bidArt_u80_text"],
						order = 4,
					},
					pStart = {
						type = 'toggle',
						name = "|cffff0000 • |r"..L["admin_option_start_auction"],
						desc = L["admin_option_start_auction_text"],
						order = 5,
					},
					pControl = {
						type = 'toggle',
						name = "|cffff0000 • |r"..L["admin_option_control_auction"],
						desc = L["admin_option_control_auction_text"],
						order = 6,
					},
					pAdmin = {
						type = 'toggle',
						name = "|cffff0000 • |r"..L["Admin Settings"],
						desc = L["admin_option_setting_admins_text"],
						order = 7,
						disabled = function()
							if v.rank > select(4, self:GetGuildPlayer(PLAYERNAME)) and self:CheckSecurity(PLAYERNAME, 'admincontrol') then
								return false
							else
								return true
							end
						end,
					},
					pAdminControl = {
						type = 'toggle',
						name = "|cffff0000 • |r"..L["admin_option_control_admins"],
						desc = L["admin_option_control_admins_text"],
						order = 8,
						disabled = function()
							if v.rank > select(4, self:GetGuildPlayer(PLAYERNAME)) and self:CheckSecurity(PLAYERNAME, 'admincontrol') then
								return false
							else
								return true
							end
						end,
					},
				},
			}
		end
	end
	
	return options
end
-- /run GigaItemAuction.db.profile.auctionSecurity.guildRank.rank7.pAdmin = true
-- /run GigaItemAuction.db.profile.auctionSecurity.guildRank.rank7.pAdminControl = true
-- /run GigaItemAuction.db.profile.auctionSecurity.guildRank.rank7.pControl = true
-- /run GigaItemAuction.db.profile.auctionSecurity.guildRank.rank7.pStart = true

function GigaItemAuction:GetOptionsSlash()
	PLAYERGUID 	= self:getMyGUID()
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	local options = {
		type = "group",
		name = L["Slash Command"],
		order = -3,
		args = {
			intro = {
				order = 1,
				type = "description",
				name = L["GIA_SLASH_DESC"],
				cmdHidden = true,
			},
			toggle = {
				order = 2,
				type = "execute",
				name = L["Toggle GIA"],
				desc = L["Toggle GIA"].." ( /gia toggle )",
				func = function() GigaItemAuction:ToggleAUCTIONFrame() end,
			},
			config = {
				order = 3,
				type = "execute",
				name = L["Configure"],
				desc = L["Open the configuration dialog"].." ( /gia config )",
				func = function() GigaItemAuction:ShowConfig() end,
				guiHidden = true,
			},
			version = {
				order = 4,
				type = "execute",
				name = L["VersionCheck"],
				desc = L["VersionCheckText"].." ( /gia version )",
				func = function() GigaItemAuction:VersionChecks() end,
				guiHidden = true,
			},
			admin = {
				order = 5,
				type = "execute",
				name = L["Admin GIA"],
				desc = L["Admin GIA"].." ( /gia admin )",
				func = function() GigaItemAuction:ToggleADMINFrame() end,
				hidden = function()
					if GigaItemAuction:CheckSecurity(PLAYERNAME, 'admin') then
						return false
					else
						return true
					end
					return false
				end,
			},
		},
	}
	return options
end



